/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from 'react';
import { shallow } from 'enzyme';

import Link from 'src/components/Link';

describe('Link', () => {
  const mockedProps = {
    tooltip: 'This is a tooltip',
    href: 'https://www.airbnb.com',
  };
  it('renders', () => {
    expect(React.isValidElement(<Link>TEST</Link>)).toBe(true);
  });
  it('renders with props', () => {
    expect(React.isValidElement(<Link {...mockedProps}>TEST</Link>)).toBe(true);
  });
  it('renders an anchor tag', () => {
    const wrapper = shallow(<Link {...mockedProps}>TEST</Link>);
    expect(wrapper.find('a')).toExist();
  });
});
